@@ -1,5 +1,5 @@
 // Copyright (c) HashiCorp, Inc.
-// SPDX-License-Identifier: MPL-2.0
+// SPDX-License-Identifier: BUSL-1.1
 
 //go:build amd64 && (darwin || windows || linux)
 
@@ -13,7 +13,6 @@ import (
 	"testing"
 
 	"github.com/google/go-cmp/cmp"
-	"github.com/mitchellh/cli"
 	"golang.org/x/mod/sumdb/dirhash"
 )
 
@@ -109,7 +108,7 @@ func TestPluginsInstallCommand_Run(t *testing.T) {
 			expectedPackerConfigDirHashBeforeInstall: "h1:47DEQpj8HBSa+/TImW+5JCeuQeRkm5NMpJWZG3hSuFU=",
 			packerConfigDir:                          cfg.dir("4_pkr_plugins_config"),
 			pluginSourceArgs:                         []string{"github.com/sylviamoss/comment", "v0.2.18", "github.com/sylviamoss/comment", "v0.2.19"},
-			want:                                     cli.RunResultHelp,
+			want:                                     1,
 			dirFiles:                                 nil,
 			expectedPackerConfigDirHashAfterInstall:  "h1:47DEQpj8HBSa+/TImW+5JCeuQeRkm5NMpJWZG3hSuFU=",
 		},
@@ -120,7 +119,7 @@ func TestPluginsInstallCommand_Run(t *testing.T) {
 			expectedPackerConfigDirHashBeforeInstall: "h1:47DEQpj8HBSa+/TImW+5JCeuQeRkm5NMpJWZG3hSuFU=",
 			packerConfigDir:                          cfg.dir("5_pkr_plugins_config"),
 			pluginSourceArgs:                         []string{},
-			want:                                     cli.RunResultHelp,
+			want:                                     1,
 			dirFiles:                                 nil,
 			expectedPackerConfigDirHashAfterInstall:  "h1:47DEQpj8HBSa+/TImW+5JCeuQeRkm5NMpJWZG3hSuFU=",
 		},
