@@ -264,6 +264,11 @@ func (c *PluginConfig) DiscoverMultiPlugin(pluginName, pluginPath string) error
 	}
 
 	pluginPrefix := pluginName + "-"
+	pluginDetails := PluginDetails{
+		Name:        pluginName,
+		Description: desc,
+		PluginPath:  pluginPath,
+	}
 
 	for _, builderName := range desc.Builders {
 		builderName := builderName // copy to avoid pointer overwrite issue
@@ -274,6 +279,8 @@ func (c *PluginConfig) DiscoverMultiPlugin(pluginName, pluginPath string) error
 		c.Builders.Set(key, func() (packersdk.Builder, error) {
 			return c.Client(pluginPath, "start", "builder", builderName).Builder()
 		})
+		PluginsDetailsStorage[fmt.Sprintf("%q-%q", PluginComponentBuilder, key)] = pluginDetails
+
 	}
 
 	if len(desc.Builders) > 0 {
@@ -289,6 +296,7 @@ func (c *PluginConfig) DiscoverMultiPlugin(pluginName, pluginPath string) error
 		c.PostProcessors.Set(key, func() (packersdk.PostProcessor, error) {
 			return c.Client(pluginPath, "start", "post-processor", postProcessorName).PostProcessor()
 		})
+		PluginsDetailsStorage[fmt.Sprintf("%q-%q", PluginComponentPostProcessor, key)] = pluginDetails
 	}
 
 	if len(desc.PostProcessors) > 0 {
@@ -304,6 +312,8 @@ func (c *PluginConfig) DiscoverMultiPlugin(pluginName, pluginPath string) error
 		c.Provisioners.Set(key, func() (packersdk.Provisioner, error) {
 			return c.Client(pluginPath, "start", "provisioner", provisionerName).Provisioner()
 		})
+		PluginsDetailsStorage[fmt.Sprintf("%q-%q", PluginComponentProvisioner, key)] = pluginDetails
+
 	}
 	if len(desc.Provisioners) > 0 {
 		log.Printf("found external %v provisioner from %s plugin", desc.Provisioners, pluginName)
@@ -318,6 +328,7 @@ func (c *PluginConfig) DiscoverMultiPlugin(pluginName, pluginPath string) error
 		c.DataSources.Set(key, func() (packersdk.Datasource, error) {
 			return c.Client(pluginPath, "start", "datasource", datasourceName).Datasource()
 		})
+		PluginsDetailsStorage[fmt.Sprintf("%q-%q", PluginComponentDataSource, key)] = pluginDetails
 	}
 	if len(desc.Datasources) > 0 {
 		log.Printf("found external %v datasource from %s plugin", desc.Datasources, pluginName)
@@ -423,3 +434,20 @@ func (c *PluginConfig) discoverInstalledComponents(path string) error {
 
 	return nil
 }
+
+type PluginComponentType string
+
+const (
+	PluginComponentBuilder       PluginComponentType = "builder"
+	PluginComponentPostProcessor PluginComponentType = "post-processor"
+	PluginComponentProvisioner   PluginComponentType = "provisioner"
+	PluginComponentDataSource    PluginComponentType = "data-source"
+)
+
+type PluginDetails struct {
+	Name        string
+	Description pluginsdk.SetDescription
+	PluginPath  string
+}
+
+var PluginsDetailsStorage = map[string]PluginDetails{}
